@@ -25,15 +25,7 @@ class ChannelInfo(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: Channel ID.
-        :type Id: str
-        :param Name: Channel name.
-        :type Name: str
-        :param Protocol: Channel protocol.
-        :type Protocol: str
-        :param Points: Channel input and output.
-        :type Points: :class:`tencentcloud.mdp.v20200527.models.PointInfo`
-        """
+        :param Id: Channel ID.\n        :type Id: str\n        :param Name: Channel name.\n        :type Name: str\n        :param Protocol: Channel protocol.\n        :type Protocol: str\n        :param Points: Channel input and output.\n        :type Points: :class:`tencentcloud.mdp.v20200527.models.PointInfo`\n        """
         self.Id = None
         self.Name = None
         self.Protocol = None
@@ -63,13 +55,7 @@ class CreateMediaPackageChannelEndpointRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: Channel ID.
-        :type Id: str
-        :param Name: Channel name.
-        :type Name: str
-        :param AuthInfo: Authentication information.
-        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`
-        """
+        :param Id: Channel ID.\n        :type Id: str\n        :param Name: Channel name.\n        :type Name: str\n        :param AuthInfo: Authentication information.\n        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`\n        """
         self.Id = None
         self.Name = None
         self.AuthInfo = None
@@ -97,11 +83,7 @@ class CreateMediaPackageChannelEndpointResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Info: The information of the created channel endpoint.
-        :type Info: :class:`tencentcloud.mdp.v20200527.models.EndpointInfo`
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param Info: The information of the created channel endpoint.\n        :type Info: :class:`tencentcloud.mdp.v20200527.models.EndpointInfo`\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Info = None
         self.RequestId = None
 
@@ -120,11 +102,7 @@ class CreateMediaPackageChannelRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Name: Channel name.
-        :type Name: str
-        :param Protocol: Channel protocol. Valid values: HLS, DASH.
-        :type Protocol: str
-        """
+        :param Name: Channel name.\n        :type Name: str\n        :param Protocol: Channel protocol. Valid values: HLS, DASH.\n        :type Protocol: str\n        """
         self.Name = None
         self.Protocol = None
 
@@ -148,11 +126,7 @@ class CreateMediaPackageChannelResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Info: Channel information.
-        :type Info: :class:`tencentcloud.mdp.v20200527.models.ChannelInfo`
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param Info: Channel information.\n        :type Info: :class:`tencentcloud.mdp.v20200527.models.ChannelInfo`\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Info = None
         self.RequestId = None
 
@@ -171,11 +145,7 @@ class DeleteMediaPackageChannelEndpointsRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: Channel ID.
-        :type Id: str
-        :param Urls: The list of endpoint URLs.
-        :type Urls: list of str
-        """
+        :param Id: Channel ID.\n        :type Id: str\n        :param Urls: The list of endpoint URLs.\n        :type Urls: list of str\n        """
         self.Id = None
         self.Urls = None
 
@@ -199,9 +169,7 @@ class DeleteMediaPackageChannelEndpointsResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -216,9 +184,7 @@ class DeleteMediaPackageChannelsRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Ids: The ID list of channels to be deleted.
-        :type Ids: list of str
-        """
+        :param Ids: The ID list of channels to be deleted.\n        :type Ids: list of str\n        """
         self.Ids = None
 
 
@@ -240,13 +206,7 @@ class DeleteMediaPackageChannelsResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SuccessInfos: The information list of channels that have been deleted.
-        :type SuccessInfos: list of ChannelInfo
-        :param FailInfos: The information list of channels that failed to be deleted.
-        :type FailInfos: list of ChannelInfo
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param SuccessInfos: The information list of channels that have been deleted.\n        :type SuccessInfos: list of ChannelInfo\n        :param FailInfos: The information list of channels that failed to be deleted.\n        :type FailInfos: list of ChannelInfo\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.SuccessInfos = None
         self.FailInfos = None
         self.RequestId = None
@@ -275,9 +235,7 @@ class DescribeMediaPackageChannelRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: Channel ID.
-        :type Id: str
-        """
+        :param Id: Channel ID.\n        :type Id: str\n        """
         self.Id = None
 
 
@@ -299,11 +257,7 @@ class DescribeMediaPackageChannelResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Info: Channel information.
-        :type Info: :class:`tencentcloud.mdp.v20200527.models.ChannelInfo`
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param Info: Channel information.\n        :type Info: :class:`tencentcloud.mdp.v20200527.models.ChannelInfo`\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Info = None
         self.RequestId = None
 
@@ -322,11 +276,7 @@ class DescribeMediaPackageChannelsRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param PageNum: Page number. Value range: [1, 1000].
-        :type PageNum: int
-        :param PageSize: The size of each page. Value range: [1, 1000].
-        :type PageSize: int
-        """
+        :param PageNum: Page number. Value range: [1, 1000].\n        :type PageNum: int\n        :param PageSize: The size of each page. Value range: [1, 1000].\n        :type PageSize: int\n        """
         self.PageNum = None
         self.PageSize = None
 
@@ -351,19 +301,7 @@ class DescribeMediaPackageChannelsResponse(AbstractModel):
     def __init__(self):
         """
         :param Infos: The list of channel outputs.
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type Infos: list of ChannelInfo
-        :param PageNum: Page number.
-        :type PageNum: int
-        :param PageSize: The size of each page.
-        :type PageSize: int
-        :param TotalNum: Total number.
-        :type TotalNum: int
-        :param TotalPage: Total number of pages.
-        :type TotalPage: int
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+Note: this field may return null, indicating that no valid values can be obtained.\n        :type Infos: list of ChannelInfo\n        :param PageNum: Page number.\n        :type PageNum: int\n        :param PageSize: The size of each page.\n        :type PageSize: int\n        :param TotalNum: Total number.\n        :type TotalNum: int\n        :param TotalPage: Total number of pages.\n        :type TotalPage: int\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Infos = None
         self.PageNum = None
         self.PageSize = None
@@ -394,15 +332,9 @@ class EndpointAuthInfo(AbstractModel):
     def __init__(self):
         """
         :param WhiteIpList: The security group allowlist in CIDR format.
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type WhiteIpList: list of str
-        :param BlackIpList: The security group blocklist in CIDR format.
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type BlackIpList: list of str
-        :param AuthKey: The authentication key. Its value is same as `X-TENCENT-PACKAGE` set in the HTTP request header.
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type AuthKey: str
-        """
+Note: this field may return null, indicating that no valid values can be obtained.\n        :type WhiteIpList: list of str\n        :param BlackIpList: The security group blocklist in CIDR format.
+Note: this field may return null, indicating that no valid values can be obtained.\n        :type BlackIpList: list of str\n        :param AuthKey: The authentication key. Its value is same as `X-TENCENT-PACKAGE` set in the HTTP request header.
+Note: this field may return null, indicating that no valid values can be obtained.\n        :type AuthKey: str\n        """
         self.WhiteIpList = None
         self.BlackIpList = None
         self.AuthKey = None
@@ -428,13 +360,7 @@ class EndpointInfo(AbstractModel):
 
     def __init__(self):
         """
-        :param Name: Endpoint name.
-        :type Name: str
-        :param Url: Endpoint URL.
-        :type Url: str
-        :param AuthInfo: Endpoint authentication information.
-        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`
-        """
+        :param Name: Endpoint name.\n        :type Name: str\n        :param Url: Endpoint URL.\n        :type Url: str\n        :param AuthInfo: Endpoint authentication information.\n        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`\n        """
         self.Name = None
         self.Url = None
         self.AuthInfo = None
@@ -463,12 +389,8 @@ class InputAuthInfo(AbstractModel):
     def __init__(self):
         """
         :param Username: Username.
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type Username: str
-        :param Password: Password.
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type Password: str
-        """
+Note: this field may return null, indicating that no valid values can be obtained.\n        :type Username: str\n        :param Password: Password.
+Note: this field may return null, indicating that no valid values can be obtained.\n        :type Password: str\n        """
         self.Username = None
         self.Password = None
 
@@ -493,11 +415,7 @@ class InputInfo(AbstractModel):
     def __init__(self):
         """
         :param Url: Channel input URL.
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type Url: str
-        :param AuthInfo: Channel input authentication information.
-        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.InputAuthInfo`
-        """
+Note: this field may return null, indicating that no valid values can be obtained.\n        :type Url: str\n        :param AuthInfo: Channel input authentication information.\n        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.InputAuthInfo`\n        """
         self.Url = None
         self.AuthInfo = None
 
@@ -523,15 +441,7 @@ class ModifyMediaPackageChannelEndpointRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: Channel ID.
-        :type Id: str
-        :param Url: Channel endpoint URL.
-        :type Url: str
-        :param Name: The channel name after modification.
-        :type Name: str
-        :param AuthInfo: The channel authentication after modification.
-        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`
-        """
+        :param Id: Channel ID.\n        :type Id: str\n        :param Url: Channel endpoint URL.\n        :type Url: str\n        :param Name: The channel name after modification.\n        :type Name: str\n        :param AuthInfo: The channel authentication after modification.\n        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`\n        """
         self.Id = None
         self.Url = None
         self.Name = None
@@ -561,9 +471,7 @@ class ModifyMediaPackageChannelEndpointResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -578,15 +486,9 @@ class ModifyMediaPackageChannelInputAuthInfoRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: Channel ID.
-        :type Id: str
-        :param Url: Channel input URL.
-        :type Url: str
-        :param ActionType: Authentication configuration type. Valid values: CLOSE, UPDATE.
+        :param Id: Channel ID.\n        :type Id: str\n        :param Url: Channel input URL.\n        :type Url: str\n        :param ActionType: Authentication configuration type. Valid values: CLOSE, UPDATE.
 CLOSE: disable authentication.
-UPDATE: update authentication.
-        :type ActionType: str
-        """
+UPDATE: update authentication.\n        :type ActionType: str\n        """
         self.Id = None
         self.Url = None
         self.ActionType = None
@@ -612,11 +514,7 @@ class ModifyMediaPackageChannelInputAuthInfoResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param AuthInfo: Channel input authentication information.
-        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.InputAuthInfo`
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param AuthInfo: Channel input authentication information.\n        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.InputAuthInfo`\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.AuthInfo = None
         self.RequestId = None
 
@@ -635,13 +533,7 @@ class ModifyMediaPackageChannelRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: Channel ID.
-        :type Id: str
-        :param Name: The channel name after modification.
-        :type Name: str
-        :param Protocol: The channel protocol after modification. Valid values: HLS, DASH.
-        :type Protocol: str
-        """
+        :param Id: Channel ID.\n        :type Id: str\n        :param Name: The channel name after modification.\n        :type Name: str\n        :param Protocol: The channel protocol after modification. Valid values: HLS, DASH.\n        :type Protocol: str\n        """
         self.Id = None
         self.Name = None
         self.Protocol = None
@@ -667,9 +559,7 @@ class ModifyMediaPackageChannelResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -684,12 +574,8 @@ class PointInfo(AbstractModel):
 
     def __init__(self):
         """
-        :param Inputs: Channel input list.
-        :type Inputs: list of InputInfo
-        :param Endpoints: Channel output list.
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type Endpoints: list of EndpointInfo
-        """
+        :param Inputs: Channel input list.\n        :type Inputs: list of InputInfo\n        :param Endpoints: Channel output list.
+Note: this field may return null, indicating that no valid values can be obtained.\n        :type Endpoints: list of EndpointInfo\n        """
         self.Inputs = None
         self.Endpoints = None
 
