@@ -25,9 +25,7 @@ class CheckInstanceRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param RegistryId: ID of the instance to be verified.
-        :type RegistryId: str
-        """
+        :param RegistryId: ID of the instance to be verified.\n        :type RegistryId: str\n        """
         self.RegistryId = None
 
 
@@ -49,13 +47,7 @@ class CheckInstanceResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param IsValidated: Verification result. true: valid, false: invalid
-        :type IsValidated: bool
-        :param RegionId: ID of the region where the instance is located.
-        :type RegionId: int
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param IsValidated: Verification result. true: valid, false: invalid\n        :type IsValidated: bool\n        :param RegionId: ID of the region where the instance is located.\n        :type RegionId: int\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.IsValidated = None
         self.RegionId = None
         self.RequestId = None
@@ -74,13 +66,7 @@ class CreateImmutableTagRulesRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param RegistryId: Instance ID
-        :type RegistryId: str
-        :param NamespaceName: Namespace
-        :type NamespaceName: str
-        :param Rule: Rule
-        :type Rule: :class:`tencentcloud.tcr.v20190924.models.ImmutableTagRule`
-        """
+        :param RegistryId: Instance ID\n        :type RegistryId: str\n        :param NamespaceName: Namespace\n        :type NamespaceName: str\n        :param Rule: Rule\n        :type Rule: :class:`tencentcloud.tcr.v20190924.models.ImmutableTagRule`\n        """
         self.RegistryId = None
         self.NamespaceName = None
         self.Rule = None
@@ -108,9 +94,7 @@ class CreateImmutableTagRulesResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -125,11 +109,7 @@ class CreateMultipleSecurityPolicyRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param RegistryId: Instance ID
-        :type RegistryId: str
-        :param SecurityGroupPolicySet: Security group policy
-        :type SecurityGroupPolicySet: list of SecurityPolicy
-        """
+        :param RegistryId: Instance ID\n        :type RegistryId: str\n        :param SecurityGroupPolicySet: Security group policy\n        :type SecurityGroupPolicySet: list of SecurityPolicy\n        """
         self.RegistryId = None
         self.SecurityGroupPolicySet = None
 
@@ -158,11 +138,7 @@ class CreateMultipleSecurityPolicyResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RegistryId: Instance ID
-        :type RegistryId: str
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RegistryId: Instance ID\n        :type RegistryId: str\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RegistryId = None
         self.RequestId = None
 
@@ -179,13 +155,7 @@ class DeleteImmutableTagRulesRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param RegistryId: Instance ID
-        :type RegistryId: str
-        :param NamespaceName: Namespace
-        :type NamespaceName: str
-        :param RuleId: Rule ID
-        :type RuleId: int
-        """
+        :param RegistryId: Instance ID\n        :type RegistryId: str\n        :param NamespaceName: Namespace\n        :type NamespaceName: str\n        :param RuleId: Rule ID\n        :type RuleId: int\n        """
         self.RegistryId = None
         self.NamespaceName = None
         self.RuleId = None
@@ -211,9 +181,7 @@ class DeleteImmutableTagRulesResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -228,11 +196,7 @@ class DeleteMultipleSecurityPolicyRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param RegistryId: Instance ID
-        :type RegistryId: str
-        :param SecurityGroupPolicySet: Security group policy
-        :type SecurityGroupPolicySet: list of SecurityPolicy
-        """
+        :param RegistryId: Instance ID\n        :type RegistryId: str\n        :param SecurityGroupPolicySet: Security group policy\n        :type SecurityGroupPolicySet: list of SecurityPolicy\n        """
         self.RegistryId = None
         self.SecurityGroupPolicySet = None
 
@@ -261,11 +225,7 @@ class DeleteMultipleSecurityPolicyResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RegistryId: Instance ID
-        :type RegistryId: str
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RegistryId: Instance ID\n        :type RegistryId: str\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RegistryId = None
         self.RequestId = None
 
@@ -282,9 +242,7 @@ class DescribeImmutableTagRulesRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param RegistryId: Instance ID
-        :type RegistryId: str
-        """
+        :param RegistryId: Instance ID\n        :type RegistryId: str\n        """
         self.RegistryId = None
 
 
@@ -307,16 +265,8 @@ class DescribeImmutableTagRulesResponse(AbstractModel):
     def __init__(self):
         """
         :param Rules: Rule list
-Note: this field may return `null`, indicating that no valid value can be obtained.
-        :type Rules: list of ImmutableTagRule
-        :param EmptyNs: Namespace with no rules created
-Note: this field may return `null`, indicating that no valid value can be obtained.
-        :type EmptyNs: list of str
-        :param Total: Total rules
-        :type Total: int
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+Note: this field may return `null`, indicating that no valid value can be obtained.\n        :type Rules: list of ImmutableTagRule\n        :param EmptyNs: Namespace with no rules created
+Note: this field may return `null`, indicating that no valid value can be obtained.\n        :type EmptyNs: list of str\n        :param Total: Total rules\n        :type Total: int\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Rules = None
         self.EmptyNs = None
         self.Total = None
@@ -342,21 +292,7 @@ class ImmutableTagRule(AbstractModel):
 
     def __init__(self):
         """
-        :param RepositoryPattern: Repository matching rule
-        :type RepositoryPattern: str
-        :param TagPattern: Tag matching rule
-        :type TagPattern: str
-        :param RepositoryDecoration: repoMatches or repoExcludes
-        :type RepositoryDecoration: str
-        :param TagDecoration: matches or excludes
-        :type TagDecoration: str
-        :param Disabled: Disabling rule
-        :type Disabled: bool
-        :param RuleId: Rule ID
-        :type RuleId: int
-        :param NsName: Namespace
-        :type NsName: str
-        """
+        :param RepositoryPattern: Repository matching rule\n        :type RepositoryPattern: str\n        :param TagPattern: Tag matching rule\n        :type TagPattern: str\n        :param RepositoryDecoration: repoMatches or repoExcludes\n        :type RepositoryDecoration: str\n        :param TagDecoration: matches or excludes\n        :type TagDecoration: str\n        :param Disabled: Disabling rule\n        :type Disabled: bool\n        :param RuleId: Rule ID\n        :type RuleId: int\n        :param NsName: Namespace\n        :type NsName: str\n        """
         self.RepositoryPattern = None
         self.TagPattern = None
         self.RepositoryDecoration = None
@@ -390,15 +326,7 @@ class ModifyImmutableTagRulesRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param RegistryId: Instance ID
-        :type RegistryId: str
-        :param NamespaceName: Namespace
-        :type NamespaceName: str
-        :param RuleId: Rule ID
-        :type RuleId: int
-        :param Rule: Rule
-        :type Rule: :class:`tencentcloud.tcr.v20190924.models.ImmutableTagRule`
-        """
+        :param RegistryId: Instance ID\n        :type RegistryId: str\n        :param NamespaceName: Namespace\n        :type NamespaceName: str\n        :param RuleId: Rule ID\n        :type RuleId: int\n        :param Rule: Rule\n        :type Rule: :class:`tencentcloud.tcr.v20190924.models.ImmutableTagRule`\n        """
         self.RegistryId = None
         self.NamespaceName = None
         self.RuleId = None
@@ -428,9 +356,7 @@ class ModifyImmutableTagRulesResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -445,15 +371,7 @@ class SecurityPolicy(AbstractModel):
 
     def __init__(self):
         """
-        :param PolicyIndex: Policy index
-        :type PolicyIndex: int
-        :param Description: Remarks
-        :type Description: str
-        :param CidrBlock: The public network IP address of the access source
-        :type CidrBlock: str
-        :param PolicyVersion: The version of the security policy
-        :type PolicyVersion: str
-        """
+        :param PolicyIndex: Policy index\n        :type PolicyIndex: int\n        :param Description: Remarks\n        :type Description: str\n        :param CidrBlock: The public network IP address of the access source\n        :type CidrBlock: str\n        :param PolicyVersion: The version of the security policy\n        :type PolicyVersion: str\n        """
         self.PolicyIndex = None
         self.Description = None
         self.CidrBlock = None
